@@ -99,8 +99,8 @@ QString RefreshX509CertsCommand::errorExitMessage(const QStringList &args) const
 {
     return xi18nc("@info",
                   "<para>An error occurred while trying to refresh X.509 certificates.</para>"
-                  "<para>The output from <command>%1</command> was: <message>%2</message></para>",
-                  args[0], errorString().replace(QLatin1Char('\n'), QStringLiteral("<br>")));
+                  "<para>The output from <command>%1</command> was: <bcode>%2</bcode></para>",
+                  args[0], errorString());
 }
 
 QString RefreshX509CertsCommand::successMessage(const QStringList &) const
