@@ -53,12 +53,14 @@
 
 #include <Libkleo/Stl_Util>
 
-#include <KLocalizedString>
 #include <KConfigGroup>
 #include <KSharedConfig>
 
 #include <vector>
 
+#include <QGpgME/CryptoConfig>
+#include <QGpgME/Protocol>
+
 using namespace Kleo;
 using namespace Kleo::Commands;
 using namespace Kleo::Dialogs;
@@ -189,6 +191,10 @@ private:
     }
     void slotUpdateRequested()
     {
+        const auto conf = QGpgME::cryptoConfig();
+        if (conf) {
+            conf->clear();
+        }
         runTests();
     }
 
