@@ -55,8 +55,8 @@ class ResultPage : public WizardPage
     Q_OBJECT
 
 public:
-    explicit ResultPage(QWidget *parent = nullptr, Qt::WindowFlags flags = 0);
-    ~ResultPage();
+    explicit ResultPage(QWidget *parent = nullptr, Qt::WindowFlags flags = {});
+    ~ResultPage() override;
 
     void setTaskCollection(const std::shared_ptr<TaskCollection> &coll);
 
