@@ -30,8 +30,8 @@
     your version.
 */
 
-#ifndef __KLEOPATRA_CRYPTO_SIGNENCRYPTFILESTASK_H__
-#define __KLEOPATRA_CRYPTO_SIGNENCRYPTFILESTASK_H__
+#ifndef __KLEOPATRA_CRYPTO_SIGNENCRYPTTASK_H__
+#define __KLEOPATRA_CRYPTO_SIGNENCRYPTTASK_H__
 
 #include <crypto/task.h>
 
@@ -73,7 +73,7 @@ public:
     void setInput(const std::shared_ptr<Input> &input);
     void setOutput(const std::shared_ptr<Output> &output);
     void setOutputFileName(const QString &fileName);
-    void setSigners(const std::vector<GpgME::Key> &singners);
+    void setSigners(const std::vector<GpgME::Key> &signers);
     void setRecipients(const std::vector<GpgME::Key> &recipients);
 
     void setSign(bool sign);
@@ -104,5 +104,5 @@ private:
 }
 }
 
-#endif /* __KLEOPATRA_CRYPTO_SIGNENCRYPTFILESTASK_H__ */
+#endif /* __KLEOPATRA_CRYPTO_SIGNENCRYPTTASK_H__ */
 
