@@ -542,7 +542,8 @@ void KleopatraApplication::openConfigDialogWithForeignParent(WId parentWId)
         if (QWidget *pw = QWidget::find(parentWId)) {
             d->configureDialog->setParent(pw, d->configureDialog->windowFlags());
         } else {
-            KWindowSystem::setMainWindow(d->configureDialog, parentWId);
+            d->configureDialog->setAttribute(Qt::WA_NativeWindow, true);
+            KWindowSystem::setMainWindow(d->configureDialog->windowHandle(), parentWId);
         }
     }
 
