@@ -58,6 +58,9 @@ public:
     virtual unsigned int classification() const = 0;
     virtual unsigned long long size() const = 0;
     virtual QString errorString() const = 0;
+    /** Whether or not the input failed. */
+    virtual bool failed() const { return false; }
+
     void finalize(); // equivalent to ioDevice()->close();
 
     static std::shared_ptr<Input> createFromPipeDevice(assuan_fd_t fd, const QString &label);
@@ -73,6 +76,7 @@ public:
 #ifndef QT_NO_CLIPBOARD
     static std::shared_ptr<Input> createFromClipboard();
 #endif
+    static std::shared_ptr<Input> createFromByteArray(QByteArray *data, const QString &label);
 };
 }
 
