@@ -370,7 +370,7 @@ void KeyListController::createActions(KActionCollection *coll)
     const action_data action_data[] = {
         // File menu
         {
-            "file_new_certificate", i18n("New Keypair..."), QString(),
+            "file_new_certificate", i18n("New Key Pair..."), QString(),
             "view-certificate-add", nullptr, nullptr, QStringLiteral("Ctrl+N"), false, true
         },
         {
@@ -444,7 +444,7 @@ void KeyListController::createActions(KActionCollection *coll)
             nullptr, nullptr, nullptr, QString(), false, true
         },
         {
-            "certificates_change_owner_trust", i18n("Change Owner Trust..."), QString(),
+            "certificates_change_owner_trust", i18n("Change Certification Trust..."), QString(),
             nullptr, nullptr, nullptr, QString(), false, true
         },
         {
