@@ -36,12 +36,15 @@
 #include <QWidget>
 
 #include <QString>
+#include <QStringList>
 
 #include <gpgme++/key.h>
 
 #include <memory>
 #include <vector>
 
+#include <KConfigGroup>
+
 class QTreeView;
 
 namespace Kleo
@@ -58,7 +61,8 @@ class KeyTreeView : public QWidget
 public:
     explicit KeyTreeView(QWidget *parent = nullptr);
     KeyTreeView(const QString &stringFilter, const std::shared_ptr<KeyFilter> &keyFilter,
-                AbstractKeyListSortFilterProxyModel *additionalProxy, QWidget *parent);
+                AbstractKeyListSortFilterProxyModel *additionalProxy, QWidget *parent,
+                const KConfigGroup &group = KConfigGroup());
     ~KeyTreeView();
 
     QTreeView *view() const
@@ -128,6 +132,7 @@ public:
 
     void disconnectSearchBar(const QObject *bar);
     bool connectSearchBar(const QObject *bar);
+    void resizeColumns();
 
 public Q_SLOTS:
     virtual void setStringFilter(const QString &text);
@@ -145,6 +150,9 @@ protected:
 private:
     void init();
     void addKeysImpl(const std::vector<GpgME::Key> &, bool);
+    void restoreExpandState();
+    void saveLayout();
+    void restoreLayout();
 
 private:
     std::vector<GpgME::Key> m_keys;
@@ -160,7 +168,12 @@ private:
     QString m_stringFilter;
     std::shared_ptr<KeyFilter> m_keyFilter;
 
+    QStringList m_expandedKeys;
+
+    KConfigGroup m_group;
+
     bool m_isHierarchical : 1;
+    bool m_onceResized : 1;
 };
 
 }
