@@ -38,6 +38,7 @@
 #include "smartcard/readerstatus.h"
 
 #include "dialogs/gencardkeydialog.h"
+#include "utils/gnupg-helper.h"
 
 #include <QProgressDialog>
 #include <QThread>
@@ -234,7 +235,8 @@ PGPCardWidget::PGPCardWidget():
 void PGPCardWidget::setCard(const OpenPGPCard *card)
 {
     const QString version = QString::fromStdString(card->cardVersion());
-    mIs21 = version == QLatin1String("2.1");
+
+    mIs21 = versionIsAtLeast("2.1", card->cardVersion().c_str());
     mVersionLabel->setText(i18nc("First placeholder is manufacturer, second placeholder is a version number",
                                  "%1 OpenPGP v%2 card", QString::fromStdString(card->manufacturer()),
                                  version));
@@ -275,7 +277,7 @@ void PGPCardWidget::doGenKey(GenCardKeyDialog *dlg)
     progress->setMinimum(0);
     progress->setModal(true);
     progress->setCancelButton(nullptr);
-    progress->setWindowTitle(i18n("Generating keys"));
+    progress->setWindowTitle(i18nc("@title:window", "Generating Keys"));
     progress->setLabel(new QLabel(i18n("This may take several minutes...")));
     GenKeyThread *workerThread = new GenKeyThread(params, mRealSerial);
     connect(workerThread, &QThread::finished, this, [this, workerThread, progress] {
@@ -500,7 +502,7 @@ void PGPCardWidget::updateKey(QLabel *label, const std::string &fpr)
                                         Formatting::UserIDs |
                                         Formatting::Fingerprint);
     }
-    label->setToolTip(toolTips.join(QStringLiteral("<br/>")));
+    label->setToolTip(toolTips.join(QLatin1String("<br/>")));
     return;
 }
 
