@@ -59,7 +59,7 @@ class TabWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit TabWidget(QWidget *parent = nullptr, Qt::WindowFlags f = 0);
+    explicit TabWidget(QWidget *parent = nullptr, Qt::WindowFlags f = {});
     ~TabWidget();
 
     void setFlatModel(AbstractKeyListModel *model);
